import React, { useMemo, useRef, useCallback, useState } from 'react';
import { Button, Avatar,Radio ,Modal, message } from 'antd';
import moment from 'moment';
import apis from '@/services/apis';
import request from '@/utils/request';
import AuthButton from '@/components/AuthButton';
import QueryTable from '@/components/QueryTable';
import BuildingSelect from '@/components/SelectButton/BuildSelect';
import OperButton from '@/components/OperButton';
import withActions from '@/components/ActionList';
import { router } from 'umi';


export default props => {
  const ref = useRef();
  const [visible, setVisible] = useState(false);
  const [data, setData] = useState(false);
  const toEdit = useCallback(row => {
    //跳转到编辑页面
    router.push({
      pathname: '/course/Edit',
      query: {
        userId: row?.userId || undefined,
      },
    });
  }, []);


  const confirm = data => () => {
    // console.log(data, "11111")
    if (data.status === 1) {
      if (data.isConsultant) {
        request({
          // ...apis.staff.check,
          ...apis.course.alterCourse,
          
          params: {
            content: data.content,
            // roleId: data.consultantPersonId,
            roleId: data.roleId,
            createdBy: data.createdBy,
          },
        }).then(res => {
          if (res.length > 0) {
          } else {
            const titleMessahe = data.isConsultant
              ? '确认取消发布此课程吗？'
              : '确认发布此课程吗？';
            Modal.confirm({
              title: titleMessahe,
              okText: '确认',
              cancelText: '取消',
              onOk() {
                // ...apis.staff.change,
                request({ ...apis.course.alterCourse, urlData: { id: data.userId, type: 'off' } }).then(
                  res => {
                    message.info('操作成功');
                    ref.current.reload();
                  },
                );
              },
            });
          }
        });
      } else {
        const titleMessahe = data.isConsultant
          ? '确认发布此课程吗？'
          : '确认取消发布此课程吗？';
        Modal.confirm({
          title: titleMessahe,
          okText: '确认',
          cancelText: '取消',
          onOk() {
            request({ ...apis.course.alterCourse, urlData: { id: data.userId, type: 'off' } }).then(
              res => {
                message.info('操作成功');
                ref.current.reload();
              },
            );
          },
        });
      }
    } else {
      Modal.confirm({
        title: '确认发布此课程吗？',
        okText: '确认',
        cancelText: '取消',
        onOk() {
          request({ ...apis.course.alterCourse, urlData: { id: data.userId, type: 'on' } }).then(res => {
            message.info('操作成功');
            ref.current.reload();
          });
        },
      });
    }
  };

  const searchFields = [
    {
      name: 'content',
      label: '课程标题',
      placeholder: '请输入课程标题',
    },
    {
      name: 'roleId',
      label: '阅读对象',
      placeholder: '请选阅读对象',
      type: 'select',
      options: [
        { label: '全部', value: '' },
        { label: '置业顾问', value: '0' },
        { label: '经纪人', value: '1' },
      ],
    },
  ];
  const tableColumns = [
    {
      title: '课程标题',
      dataIndex: 'content',
      key: 'content',
      align: 'center',
    },
    {
      title:'课程主图',
      dataIndex:'curriculumImg',
      key:'curriculumImg',
      align:'center',
      render: (_,record) => <img src={record.curriculumImg} style={{ width: '165px', height: '104px' }} />,
      // render:(record)=>(<img src={require(record)}/>)
    },
    {
      title: '阅读人数',
      dataIndex: 'lookNum',
      key: 'lookNum',
      align: 'center',
    },
    {
      title: '阅读对象',
      dataIndex: 'roleId',
      key: 'roleId',
      align: 'center',
      render: text  => (text === '0' ? '置业顾问' :text === '1' ? '经纪人':'置业顾问&经纪人'),
    },
    
    {
      //权重---
      title: '权重',
      dataIndex: 'weight',
      key: 'weight',
      align: 'center',
      // render: (_, record) => <><span>{record.numear = '20'}</span></>,
    },
    {
      title: '操作',
      key: 'isPublish',
      //isPublish
      align: 'center',
      render: withActions(
        (_, row) => [
          <AuthButton name="admin.building.public" noRight={null}>
            <OperButton onClick={confirm(row)}> {row.status === 1 ? '取消发布' : '发布'}</OperButton>
          </AuthButton>,
          <AuthButton name="admin.building.delete" noRight={null}>
               <OperButton onClick>添加标签</OperButton>
               <OperButton onClick={()=>toEdit(row)}>{row.status ===1? '编辑':''}</OperButton>
               {/* <OperButton onClick={()=>toEdit(row)} >编辑</OperButton> */}
          </AuthButton>,
        ],
        { noMargin: true },
      ),
    },
  ];
  const actionRender = () => {
    return (
      <AuthButton name="admin.newclassType.add" noRight={null}>
        <Button type="primary" icon="plus" onClick={() => toEdit()}>
          新增
        </Button>
      </AuthButton>
    );
  };

  return (
    <>
      <QueryTable
        ref={ref}
        rowKey="curriculumId"
        // api={apis.staff.taUser}
        
        api={apis.course.Tablecourse}
        columns={tableColumns}
        searchFields={searchFields}
        actionRender={actionRender}
      />
    </>
  );
};
